package cs

import (
	"fmt"
	"os"
	"testing"
)

/**
 * 客服工单服务，单元测试
 */

// 获取faq树状数据
func TestGetFaq(t *testing.T) {
	client, newErr := NewClient()
	if newErr != nil {
		panic(newErr)
	}

	req := CreateGetFaqRequest()
	faq, err := client.GetFaq(req)
	if err != nil {
		t.Error(err)
		return
	}

	fmt.Printf(fmt.Sprintf("%#+v", faq))
}

// 获取玩家基本信息
func TestGetUserInfo(t *testing.T) {
	client, newErr := NewClient()
	if newErr != nil {
		panic(newErr)
	}
	req := CreateGetUserInfoRequest("ws45265737")
	info, err := client.GetUserInfo(req)
	if err != nil {
		t.Error(err)
		return
	}

	fmt.Printf(fmt.Sprintf("%v", info))
}

// 获取玩家角色列表
func TestGetUserRoleList(t *testing.T) {
	client, newErr := NewClient()
	if newErr != nil {
		panic(newErr)
	}
	req := CreateGetUserRoleListRequest(int64(63610626), int64(2850))
	info, err := client.GetCsUserRoleList(req)
	if err != nil {
		t.Error(err)
		return
	}
	if info.Code != 0 {
		t.Error("获取玩家角色列表失败")
		fmt.Printf(fmt.Sprintf("%v", info))
		return
	}
	fmt.Printf(fmt.Sprintf("%v", info))
}

// 获取玩家区服列表
func TestGetUserServerList(t *testing.T) {
	client, newErr := NewClient()
	if newErr != nil {
		panic(newErr)
	}
	req := CreateGetUserServerListRequest(int64(63610626), int64(2850))
	info, err := client.GetUserServerList(req)
	if err != nil {
		t.Error(err)
		return
	}
	if info.Code != 0 {
		t.Error("获取玩家区服列表失败")
		fmt.Printf(fmt.Sprintf("%v", info))
		return
	}
	fmt.Printf(fmt.Sprintf("%v", info))
}

// 给玩家发送短信
func TestSendSms(t *testing.T) {
	client, newErr := NewClient()
	if newErr != nil {
		panic(newErr)
	}
	req := CreateSendSmsRequest(SendSmsReq{
		Phone: "13725263463",
	})
	info, err := client.SendSmsCode(req)
	if err != nil {
		t.Error(err)
		return
	}
	if info.Code != 0 {
		t.Error("给玩家发送短信失败")
	}
	fmt.Printf(fmt.Sprintf("%v", info))
}

// 工单图片上传
func TestUpload(t *testing.T) {
	client, newErr := NewClient()
	if newErr != nil {
		panic(newErr)
	}
	// 读取文件流
	file, err := os.ReadFile("test.png")
	if err != nil {
		t.Error(err)
		return
	}
	req := CreateUploadRequest()
	req.FileStream = file
	res, err := client.Upload(req)
	if err != nil {
		t.Error(err)
		return
	}
	if res.Code != 0 {
		t.Error("工单图片上传失败")
	}
	fmt.Printf(fmt.Sprintf("%v", res))
}
